@@ -229,7 +229,7 @@ AptProtocol::AptProtocol( const TQCString &pool_socket, const TQCString &app_soc
   m_stylesheet = dirs->findResource( "data", "tdeio_apt/tdeio_apt.css" );
 
   m_logo = dirs->findResource( "data", "tdeio_apt/" 
-          + TDEGlobal::config() -> readEntryUntranslated("logo", "kdedeb_logo.png" ) );
+          + TDEGlobal::config() -> readEntryUntranslated("logo", "tdedeb_logo.png" ) );
 
   m_header_background = dirs->findResource( "data", "tdeio_apt/" 
           + TDEGlobal::config() -> readEntryUntranslated("background", "headerbg.png" ) );
